==> react-7.11.0.tgz: package/es/Footer/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

/**
 * @category layout
 * @component footer
 * @variations collab-ui-react
 */
import React from 'react';
import PropTypes from 'prop-types';

var Footer =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Footer, _React$Component);

  function Footer() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Footer.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        color = _this$props.color,
        logo = _this$props.logo,
        copyright = _this$props.copyright,
        social = _this$props.social,
        className = _this$props.className,
        children = _this$props.children;
    var footerTopSection = children && React.createElement("section", {
      className: "cui-footer__top"
    }, children);
    var footerBottomSection = (logo || copyright || social) && React.createElement("section", {
      className: "cui-footer__bottom"
    }, (logo || copyright) && React.createElement("span", {
      className: "cui-footer__bottom--position-left"
    }, React.createElement("span", {
      className: "cui-footer__logo"
    }, logo), copyright), social && React.createElement("span", {
      className: "cui-footer__bottom--position-right"
    }, social));
    return React.createElement("footer", {
      className: "cui-footer" + (" cui-footer--" + color) + (" " + className)
    }, footerTopSection, footerBottomSection);
  };

  return Footer;
}(React.Component);

Footer.displayName = 'Footer';
export { Footer as default };
Footer.propTypes = {
  color: PropTypes.string,
  logo: PropTypes.node,
  copyright: PropTypes.string,
  social: PropTypes.node,
  className: PropTypes.string,
  children: PropTypes.node
};
Footer.defaultProps = {
  color: 'dark',
  logo: null,
  copyright: '',
  social: null,
  className: '',
  children: null
};
/**
* @name Footer
* @description default footer
*
* @category layout
* @component footer
* @section default
*
* @js
import { SocialList, Icon, List, ListItem } from '@collab-ui/react';

export default class DefaultFooter extends React.PureComponent {
  render() {
    const copyright = '2018 Cisco and /or its affiliate';
    const social = (
      <SocialList>
        <List tabType='horizontal' className='social-list'>
          <ListItem link='https://www.facebook.com'>
            <i className='icon icon-facebook-circle_24' />
          </ListItem>
          <ListItem link='https://www.twitter.com'>
            <i className='icon icon-twitter-circle_24' />
          </ListItem>
          <ListItem link='https://www.linkedin.com'>
            <i className='icon icon-linkedin-circle_24' />
          </ListItem>
        </List>
      </SocialList>
    );

    return (
      <div className='row'>
        <Footer
          logo={<i className='icon icon-cisco-logo' />}
          copyright='2018 Cisco and /or its affiliate'
          social={social}
        >
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Connect</h5>
            <List>
              <ListItem label='24/7 Support' />
              <ListItem label='Developer Events' />
              <ListItem label='Contact Sales' />
            </List>
          </div>
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Handy Links</h5>
            <List>
              <ListItem label='Cisco Webex Ambassadors' />
              <ListItem label='Cisco Webex Control Hub' />
              <ListItem label='Cisco Webex Innovation Fund' />
            </List>
          </div>
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Resources</h5>
            <List>
              <ListItem label='Open Source Bot Starter Kits' />
              <ListItem label='Download Cisco Webex Teams' />
              <ListItem label='Devnet Learning Labs' />
            </List>
          </div>
          <div className='columns medium-3'>
            <List>
              <ListItem label='Terms Of Service' />
              <ListItem label='Privacy Policy' />
              <ListItem label='Cookie Policy' />
              <ListItem label='Trademarks' />
            </List>
          </div>
        </Footer>
      </div>
    );
  }
}
**/

==> react-9.10.0.tgz: package/es/Footer/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

/**
 * @category layout
 * @component footer
 * @variations collab-ui-react
 */
import React from 'react';
import PropTypes from 'prop-types';

var Footer =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Footer, _React$Component);

  function Footer() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Footer.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        color = _this$props.color,
        logo = _this$props.logo,
        copyright = _this$props.copyright,
        social = _this$props.social,
        className = _this$props.className,
        children = _this$props.children;
    var footerTopSection = children && React.createElement("section", {
      className: "cui-footer__top"
    }, children);
    var footerBottomSection = (logo || copyright || social) && React.createElement("section", {
      className: "cui-footer__bottom"
    }, (logo || copyright) && React.createElement("span", {
      className: "cui-footer__bottom--position-left"
    }, React.createElement("span", {
      className: "cui-footer__logo"
    }, logo), copyright), social && React.createElement("span", {
      className: "cui-footer__bottom--position-right"
    }, social));
    return React.createElement("footer", {
      className: "cui-footer" + (" cui-footer--" + color) + (" " + className)
    }, footerTopSection, footerBottomSection);
  };

  return Footer;
}(React.Component);

export { Footer as default };
Footer.propTypes = {
  /** @prop Children nodes to render inside the Footer | null */
  children: PropTypes.node,

  /** @prop Optional css class string | '' */
  className: PropTypes.string,

  /** @prop Optional color css styling | 'dark' */
  color: PropTypes.string,

  /** @prop Set the copyright within the Footer | '' */
  copyright: PropTypes.string,

  /** @prop Set the logo within the Footer | null */
  logo: PropTypes.node,

  /** @prop Node containing social media links | null */
  social: PropTypes.node
};
Footer.defaultProps = {
  children: null,
  className: '',
  color: 'dark',
  copyright: '',
  logo: null,
  social: null
};
Footer.displayName = 'Footer';
/**
* @name Footer
* @description default footer
*
* @category layout
* @component footer
* @section default
*
* @js
import { SocialList, Icon, List, ListItem } from '@collab-ui/react';

export default class DefaultFooter extends React.PureComponent {
  render() {
    const copyright = '2018 Cisco and /or its affiliate';
    const social = (
      <SocialList>
        <List tabType='horizontal' className='social-list'>
          <ListItem link='https://www.facebook.com'>
            <i className='icon icon-facebook-circle_24' />
          </ListItem>
          <ListItem link='https://www.twitter.com'>
            <i className='icon icon-twitter-circle_24' />
          </ListItem>
          <ListItem link='https://www.linkedin.com'>
            <i className='icon icon-linkedin-circle_24' />
          </ListItem>
        </List>
      </SocialList>
    );

    return (
      <div className='row'>
        <Footer
          logo={<i className='icon icon-cisco-logo' />}
          copyright='2018 Cisco and /or its affiliate'
          social={social}
        >
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Connect</h5>
            <List>
              <ListItem label='24/7 Support' />
              <ListItem label='Developer Events' />
              <ListItem label='Contact Sales' />
            </List>
          </div>
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Handy Links</h5>
            <List>
              <ListItem label='Cisco Webex Ambassadors' />
              <ListItem label='Cisco Webex Control Hub' />
              <ListItem label='Cisco Webex Innovation Fund' />
            </List>
          </div>
          <div className='columns medium-3'>
            <h5 className='cui-footer__list-item-title'>Resources</h5>
            <List>
              <ListItem label='Open Source Bot Starter Kits' />
              <ListItem label='Download Cisco Webex Teams' />
              <ListItem label='Devnet Learning Labs' />
            </List>
          </div>
          <div className='columns medium-3'>
            <List>
              <ListItem label='Terms Of Service' />
              <ListItem label='Privacy Policy' />
              <ListItem label='Cookie Policy' />
              <ListItem label='Trademarks' />
            </List>
          </div>
        </Footer>
      </div>
    );
  }
}
**/
